# coding: utf-8

"""
    Influx API Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from influxdb_client.api_client import ApiClient


class VariablesService(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_variables_id(self, variable_id, **kwargs):  # noqa: E501
        """delete a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_variables_id(variable_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: id of the variable (required)
        :param str zap_trace_span: OpenTracing span context
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_variables_id_with_http_info(variable_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_variables_id_with_http_info(variable_id, **kwargs)  # noqa: E501
            return data

    def delete_variables_id_with_http_info(self, variable_id, **kwargs):  # noqa: E501
        """delete a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_variables_id_with_http_info(variable_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: id of the variable (required)
        :param str zap_trace_span: OpenTracing span context
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['variable_id', 'zap_trace_span']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_variables_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'variable_id' is set
        if ('variable_id' not in local_var_params or
                local_var_params['variable_id'] is None):
            raise ValueError("Missing the required parameter `variable_id` when calling `delete_variables_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'variable_id' in local_var_params:
            path_params['variableID'] = local_var_params['variable_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/variables/{variableID}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_variables_id_labels_id(self, variable_id, label_id, **kwargs):  # noqa: E501
        """delete a label from a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_variables_id_labels_id(variable_id, label_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: ID of the variable (required)
        :param str label_id: the label id to delete (required)
        :param str zap_trace_span: OpenTracing span context
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_variables_id_labels_id_with_http_info(variable_id, label_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_variables_id_labels_id_with_http_info(variable_id, label_id, **kwargs)  # noqa: E501
            return data

    def delete_variables_id_labels_id_with_http_info(self, variable_id, label_id, **kwargs):  # noqa: E501
        """delete a label from a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_variables_id_labels_id_with_http_info(variable_id, label_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: ID of the variable (required)
        :param str label_id: the label id to delete (required)
        :param str zap_trace_span: OpenTracing span context
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['variable_id', 'label_id', 'zap_trace_span']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_variables_id_labels_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'variable_id' is set
        if ('variable_id' not in local_var_params or
                local_var_params['variable_id'] is None):
            raise ValueError("Missing the required parameter `variable_id` when calling `delete_variables_id_labels_id`")  # noqa: E501
        # verify the required parameter 'label_id' is set
        if ('label_id' not in local_var_params or
                local_var_params['label_id'] is None):
            raise ValueError("Missing the required parameter `label_id` when calling `delete_variables_id_labels_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'variable_id' in local_var_params:
            path_params['variableID'] = local_var_params['variable_id']  # noqa: E501
        if 'label_id' in local_var_params:
            path_params['labelID'] = local_var_params['label_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/variables/{variableID}/labels/{labelID}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_variables(self, **kwargs):  # noqa: E501
        """get all variables  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_variables(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str zap_trace_span: OpenTracing span context
        :param str org: specifies the organization name of the resource
        :param str org_id: specifies the organization id of the resource
        :return: Variables
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_variables_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_variables_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_variables_with_http_info(self, **kwargs):  # noqa: E501
        """get all variables  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_variables_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str zap_trace_span: OpenTracing span context
        :param str org: specifies the organization name of the resource
        :param str org_id: specifies the organization id of the resource
        :return: Variables
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['zap_trace_span', 'org', 'org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_variables" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'org' in local_var_params:
            query_params.append(('org', local_var_params['org']))  # noqa: E501
        if 'org_id' in local_var_params:
            query_params.append(('orgID', local_var_params['org_id']))  # noqa: E501

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/variables', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Variables',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_variables_id(self, variable_id, **kwargs):  # noqa: E501
        """get a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_variables_id(variable_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: ID of the variable (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Variable
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_variables_id_with_http_info(variable_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_variables_id_with_http_info(variable_id, **kwargs)  # noqa: E501
            return data

    def get_variables_id_with_http_info(self, variable_id, **kwargs):  # noqa: E501
        """get a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_variables_id_with_http_info(variable_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: ID of the variable (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Variable
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['variable_id', 'zap_trace_span']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_variables_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'variable_id' is set
        if ('variable_id' not in local_var_params or
                local_var_params['variable_id'] is None):
            raise ValueError("Missing the required parameter `variable_id` when calling `get_variables_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'variable_id' in local_var_params:
            path_params['variableID'] = local_var_params['variable_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/variables/{variableID}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Variable',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_variables_id_labels(self, variable_id, **kwargs):  # noqa: E501
        """list all labels for a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_variables_id_labels(variable_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: ID of the variable (required)
        :param str zap_trace_span: OpenTracing span context
        :return: LabelsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_variables_id_labels_with_http_info(variable_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_variables_id_labels_with_http_info(variable_id, **kwargs)  # noqa: E501
            return data

    def get_variables_id_labels_with_http_info(self, variable_id, **kwargs):  # noqa: E501
        """list all labels for a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_variables_id_labels_with_http_info(variable_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: ID of the variable (required)
        :param str zap_trace_span: OpenTracing span context
        :return: LabelsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['variable_id', 'zap_trace_span']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_variables_id_labels" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'variable_id' is set
        if ('variable_id' not in local_var_params or
                local_var_params['variable_id'] is None):
            raise ValueError("Missing the required parameter `variable_id` when calling `get_variables_id_labels`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'variable_id' in local_var_params:
            path_params['variableID'] = local_var_params['variable_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/variables/{variableID}/labels', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LabelsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def patch_variables_id(self, variable_id, variable, **kwargs):  # noqa: E501
        """update a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.patch_variables_id(variable_id, variable, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: id of the variable (required)
        :param Variable variable: variable update to apply (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Variable
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.patch_variables_id_with_http_info(variable_id, variable, **kwargs)  # noqa: E501
        else:
            (data) = self.patch_variables_id_with_http_info(variable_id, variable, **kwargs)  # noqa: E501
            return data

    def patch_variables_id_with_http_info(self, variable_id, variable, **kwargs):  # noqa: E501
        """update a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.patch_variables_id_with_http_info(variable_id, variable, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: id of the variable (required)
        :param Variable variable: variable update to apply (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Variable
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['variable_id', 'variable', 'zap_trace_span']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method patch_variables_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'variable_id' is set
        if ('variable_id' not in local_var_params or
                local_var_params['variable_id'] is None):
            raise ValueError("Missing the required parameter `variable_id` when calling `patch_variables_id`")  # noqa: E501
        # verify the required parameter 'variable' is set
        if ('variable' not in local_var_params or
                local_var_params['variable'] is None):
            raise ValueError("Missing the required parameter `variable` when calling `patch_variables_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'variable_id' in local_var_params:
            path_params['variableID'] = local_var_params['variable_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'variable' in local_var_params:
            body_params = local_var_params['variable']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/variables/{variableID}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Variable',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_variables(self, variable, **kwargs):  # noqa: E501
        """create a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_variables(variable, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Variable variable: variable to create (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Variable
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_variables_with_http_info(variable, **kwargs)  # noqa: E501
        else:
            (data) = self.post_variables_with_http_info(variable, **kwargs)  # noqa: E501
            return data

    def post_variables_with_http_info(self, variable, **kwargs):  # noqa: E501
        """create a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_variables_with_http_info(variable, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Variable variable: variable to create (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Variable
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['variable', 'zap_trace_span']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_variables" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'variable' is set
        if ('variable' not in local_var_params or
                local_var_params['variable'] is None):
            raise ValueError("Missing the required parameter `variable` when calling `post_variables`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'variable' in local_var_params:
            body_params = local_var_params['variable']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/variables', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Variable',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_variables_id_labels(self, variable_id, label_mapping, **kwargs):  # noqa: E501
        """add a label to a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_variables_id_labels(variable_id, label_mapping, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: ID of the variable (required)
        :param LabelMapping label_mapping: label to add (required)
        :param str zap_trace_span: OpenTracing span context
        :return: LabelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_variables_id_labels_with_http_info(variable_id, label_mapping, **kwargs)  # noqa: E501
        else:
            (data) = self.post_variables_id_labels_with_http_info(variable_id, label_mapping, **kwargs)  # noqa: E501
            return data

    def post_variables_id_labels_with_http_info(self, variable_id, label_mapping, **kwargs):  # noqa: E501
        """add a label to a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_variables_id_labels_with_http_info(variable_id, label_mapping, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: ID of the variable (required)
        :param LabelMapping label_mapping: label to add (required)
        :param str zap_trace_span: OpenTracing span context
        :return: LabelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['variable_id', 'label_mapping', 'zap_trace_span']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_variables_id_labels" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'variable_id' is set
        if ('variable_id' not in local_var_params or
                local_var_params['variable_id'] is None):
            raise ValueError("Missing the required parameter `variable_id` when calling `post_variables_id_labels`")  # noqa: E501
        # verify the required parameter 'label_mapping' is set
        if ('label_mapping' not in local_var_params or
                local_var_params['label_mapping'] is None):
            raise ValueError("Missing the required parameter `label_mapping` when calling `post_variables_id_labels`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'variable_id' in local_var_params:
            path_params['variableID'] = local_var_params['variable_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'label_mapping' in local_var_params:
            body_params = local_var_params['label_mapping']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/variables/{variableID}/labels', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LabelResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def put_variables_id(self, variable_id, variable, **kwargs):  # noqa: E501
        """replace a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_variables_id(variable_id, variable, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: id of the variable (required)
        :param Variable variable: variable to replace (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Variable
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.put_variables_id_with_http_info(variable_id, variable, **kwargs)  # noqa: E501
        else:
            (data) = self.put_variables_id_with_http_info(variable_id, variable, **kwargs)  # noqa: E501
            return data

    def put_variables_id_with_http_info(self, variable_id, variable, **kwargs):  # noqa: E501
        """replace a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_variables_id_with_http_info(variable_id, variable, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: id of the variable (required)
        :param Variable variable: variable to replace (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Variable
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['variable_id', 'variable', 'zap_trace_span']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_variables_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'variable_id' is set
        if ('variable_id' not in local_var_params or
                local_var_params['variable_id'] is None):
            raise ValueError("Missing the required parameter `variable_id` when calling `put_variables_id`")  # noqa: E501
        # verify the required parameter 'variable' is set
        if ('variable' not in local_var_params or
                local_var_params['variable'] is None):
            raise ValueError("Missing the required parameter `variable` when calling `put_variables_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'variable_id' in local_var_params:
            path_params['variableID'] = local_var_params['variable_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'variable' in local_var_params:
            body_params = local_var_params['variable']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/variables/{variableID}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Variable',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)
