# coding: utf-8

"""
    Influx API Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class DocumentCreate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'meta': 'DocumentMeta',
        'content': 'object',
        'org': 'str',
        'org_id': 'str',
        'labels': 'list[str]'
    }

    attribute_map = {
        'meta': 'meta',
        'content': 'content',
        'org': 'org',
        'org_id': 'orgID',
        'labels': 'labels'
    }

    def __init__(self, meta=None, content=None, org=None, org_id=None, labels=None):  # noqa: E501
        """DocumentCreate - a model defined in OpenAPI"""  # noqa: E501

        self._meta = None
        self._content = None
        self._org = None
        self._org_id = None
        self._labels = None
        self.discriminator = None

        self.meta = meta
        self.content = content
        if org is not None:
            self.org = org
        if org_id is not None:
            self.org_id = org_id
        if labels is not None:
            self.labels = labels

    @property
    def meta(self):
        """Gets the meta of this DocumentCreate.  # noqa: E501


        :return: The meta of this DocumentCreate.  # noqa: E501
        :rtype: DocumentMeta
        """
        return self._meta

    @meta.setter
    def meta(self, meta):
        """Sets the meta of this DocumentCreate.


        :param meta: The meta of this DocumentCreate.  # noqa: E501
        :type: DocumentMeta
        """
        if meta is None:
            raise ValueError("Invalid value for `meta`, must not be `None`")  # noqa: E501

        self._meta = meta

    @property
    def content(self):
        """Gets the content of this DocumentCreate.  # noqa: E501


        :return: The content of this DocumentCreate.  # noqa: E501
        :rtype: object
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this DocumentCreate.


        :param content: The content of this DocumentCreate.  # noqa: E501
        :type: object
        """
        if content is None:
            raise ValueError("Invalid value for `content`, must not be `None`")  # noqa: E501

        self._content = content

    @property
    def org(self):
        """Gets the org of this DocumentCreate.  # noqa: E501

        must specify one of orgID and org  # noqa: E501

        :return: The org of this DocumentCreate.  # noqa: E501
        :rtype: str
        """
        return self._org

    @org.setter
    def org(self, org):
        """Sets the org of this DocumentCreate.

        must specify one of orgID and org  # noqa: E501

        :param org: The org of this DocumentCreate.  # noqa: E501
        :type: str
        """

        self._org = org

    @property
    def org_id(self):
        """Gets the org_id of this DocumentCreate.  # noqa: E501

        must specify one of orgID and org  # noqa: E501

        :return: The org_id of this DocumentCreate.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this DocumentCreate.

        must specify one of orgID and org  # noqa: E501

        :param org_id: The org_id of this DocumentCreate.  # noqa: E501
        :type: str
        """

        self._org_id = org_id

    @property
    def labels(self):
        """Gets the labels of this DocumentCreate.  # noqa: E501

        this is an array of label IDs that will be added as labels to the document  # noqa: E501

        :return: The labels of this DocumentCreate.  # noqa: E501
        :rtype: list[str]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this DocumentCreate.

        this is an array of label IDs that will be added as labels to the document  # noqa: E501

        :param labels: The labels of this DocumentCreate.  # noqa: E501
        :type: list[str]
        """

        self._labels = labels

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocumentCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
